\name{AdvanceState}
\alias{.lec.AdvanceState}
\title{Advance the state of a stream}
\description{\code{.lec.AdvanceState} advances the state of a stream by
  \eqn{n} steps (see bellow).
}
\usage{
.lec.AdvanceState (name, e, c)
}
\arguments{
  \item{name}{name of the stream.}
  \item{e, c}{if \eqn{e > 0} then \eqn{n = 2^e + c}; if \eqn{e < 0} then \eqn{n = -2^{-e} + c};
  if \eqn{e = 0} then \eqn{n = c.}}
}

\value{None.}
\details{\code{.lec.AdvanceState} is a wrapper function for the C
  function \code{RngStream_AdvanceState} (L'Ecuyer et al, 2002).}

\references{P. L'Ecuyer, R. Simard, E.J.Chen and W.D.Kelton: An
  Object-Oriented Random-Number Package With Many Long Streams and
  Substreams; Operations Research, vol. 50, nr. 6, 2002.}
\keyword{distribution}


\eof
\name{CreateStream}
\alias{.lec.CreateStream}
\title{Spawn new streams}
\description{\code{.lec.CreateStream} creates new streams of random
  numbers.}
\usage{
.lec.CreateStream (names)
}
\arguments{
  \item{names}{a character string or a vector of character strings
    naming the streams to be created. The argument must be
    provided and the names must be unique within the set of existing
    streams. If for one \code{i} a
    stream of the name \code{names[i]} already exists,
    its state is replaced by the
    state of the new created stream.}
}
\value{None.}
\details{\code{.lec.CreateStream} is a wrapper function for the C
  function \code{RngStream_CreateStream} (L'Ecuyer et al, 2002). The state of
  the created stream returned by the C function is stored in the global
  object \code{.lec.Random.seed.table}.
}
\references{P. L'Ecuyer, R. Simard, E.J.Chen and W.D.Kelton: An
  Object-Oriented Random-Number Package With Many Long Streams and
  Substreams; Operations Research, vol. 50, nr. 6, 2002.}
\examples{
nstreams <- 10       # number of streams
names <- paste("mystream",1:nstreams,sep="")
.lec.CreateStream(names)
.lec.WriteStateFull(names)
}
\keyword{distribution}

\eof
\name{CurrentStream}
\alias{.lec.CurrentStream}
\alias{.lec.CurrentStreamEnd}
\title{Set/unset the current stream}
\description{\code{.lec.CurrentStream} sets the current stream for usage
  with the standard R functions for generating random numbers such as
  \code{\link{runif}} or \code{\link{rnorm}}. \code{.lec.CurrentStreamEnd unsets it.}}
\usage{
.lec.CurrentStream (name)
.lec.CurrentStreamEnd (kind.old = c("Marsaglia-Multicarry",
                         "Kinderman-Ramage"))
}
\arguments{
  \item{name}{a character string giving the name of the stream.}
  \item{kind.old}{a length 2 character vector, the old rng kinds
  (possiblly returned by \code{.lec.CurrentStream}).}
}
\value{\code{.lec.CurrentStream} returns a two-element character vector of the RNG and normal kinds
  in use before the call. \code{.lec.CurrentStreamEnd} returns a character string giving the name of the unset current stream.
}
\details{\code{.lec.CurrentStream} sets the RNGkind to user-defined. All succeeding calls of R built-in genertors  will
  generate random numbers from the stream \code{name}, until
  \code{.lec.CurrentStreamEnd} is called. \code{.lec.CurrentStreamEnd} updates the RNG state of the stream \code{name} in the
  table \code{.lec.Random.seed.table} and 
  sets the RNGkind to \code{kind.old}. These two functions are meant to be always used as a pair.  Thus, one can arbitrarily switch
  generating between different streams.
}
\examples{
nstreams <- 10       # number of streams
names <- paste("mystream",1:nstreams,sep="")
.lec.CreateStream(names)
for (i in 1:nstreams) {  # generate 10 RNs from each stream
   .lec.CurrentStream(names[i])
   print(paste("stream no.",i))
   print(runif(10))
   .lec.CurrentStreamEnd()
}
}
\keyword{distribution}

\eof
\name{DeleteStream}
\alias{.lec.DeleteStream}
\title{Remove streams}
\description{\code{.lec.DeleteStream} removes streams from the global state table.}
\usage{
.lec.DeleteStream (names)
}
\arguments{
  \item{names}{a character string or a vector of character strings
    naming the streams to be deleted.}
}
\value{None.}
\details{All streams given in the argument \code{names} are removed from
  the table \code{.lec.Random.seed.table}.
}
\keyword{distribution}

\eof
\name{GetState}
\alias{.lec.GetState}
\title{Return current state of a stream}
\description{Returns current state (Cg values) of the stream \code{name}.}
\usage{.lec.GetState (name)
}
\arguments{
  \item{name}{a character string giving the name of the stream.}
}
\value{a vector of six integer values that identifies the current state of the
  stream.}
\keyword{distribution}
\seealso{\code{\link[rlecuyer]{SetPackageSeed}}}

\eof
\name{GetStreams}
\alias{.lec.GetStreams}
\title{Return names of existing streams}
\description{Returns names of existing streams stored in
  \code{.lec.Random.seed.table}. }
\usage{.lec.GetStreams ()
}

\value{a vector of character strings.}

\keyword{distribution}

\eof
\name{IncreasedPrecis}
\alias{.lec.IncreasedPrecis}
\title{Switch between 32 and 53 bits of resolution}
\description{Switch between 32 and 53 bits of resolution as described in
  L'Ecuyer et al (2002).
}
\usage{
.lec.IncreasedPrecis (name, incp=FALSE)
}
\arguments{
  \item{name}{name of the stream.}
  \item{incp}{see  L'Ecuyer et al (2002).}
}
\value{None.}
\details{\code{.lec.IncreasedPrecis} is a wrapper function for the C
  function \code{RngStream_IncreasedPrecis}.}

\references{P. L'Ecuyer, R. Simard, E.J.Chen and W.D.Kelton: An
  Object-Oriented Random-Number Package With Many Long Streams and
  Substreams; Operations Research, vol. 50, nr. 6, 2002.}
\keyword{distribution}

\eof
\name{ResetStream}
\alias{.lec.ResetNextSubstream}
\alias{.lec.ResetStartSubstream}
\alias{.lec.ResetStartStream}
\title{Reset the state of a stream}
\description{Resets the state of a stream to its initial state, beginning of the current substream or beginning of the next substream.}
\usage{
.lec.ResetNextSubstream(name)
.lec.ResetStartStream(name)
.lec.ResetStartSubstream(name)
}
\arguments{
  \item{name}{a character string giving the name of the stream.}
 }
}
\details{\code{.lec.ResetNextSubstream} reinitializes the stream to the
  beginning of its next substream.

  \code{.lec.ResetStartStream} reinitializes the stream to its initial state.

  \code{.lec.ResetStartSubstream} reinitializes the stream to the
  beginning of its current substream.
}
\value{None.}
\keyword{distribution}
\seealso{\code{\link[rlecuyer]{SetPackageSeed}}}

\eof
\name{SetAntithetic}
\alias{.lec.SetAntithetic}
\title{Switch between U and 1-U variates}
\description{Switches between \eqn{U} and \eqn{1-U} variates.
}
\usage{
.lec.SetAntithetic (name, anti=FALSE)
}
\arguments{
  \item{name}{name of the stream.}
  \item{anti}{if \code{anti=TRUE} then antithetic variates are generated (i.e. \eqn{1-U}), until this function is called again with \code{anti=FALSE}.}
}
\value{None.}
\keyword{distribution}


\eof
\name{SetPackageSeed}
\alias{.lec.SetSeed}
\alias{.lec.SetPackageSeed}
\title{Set the initial seed of the package or stream}
\description{Sets the initial seed of the package or stream.}
\usage{
.lec.SetPackageSeed(seed)
.lec.SetSeed (name, seed)
}
\arguments{
  \item{name}{a character string giving the name of the stream.}
  \item{seed}{a vector of six integers. If it is shorter, the seed is
    extended to the length of 6 by default values 12345. If it is
    longer, it is truncated to the length of 6 by eliminating the last
elements. } } 

\details{Each state of a stream is given by three
integer vectors of length 6: Ig gives the initital state of the
stream, Bg gives the starting state of the substream that contains the
current state, Cg gives the current state.  Function
\code{.lec.SetPackageSeed} sets Cg, Bg and Ig to the value of
\code{seed}. Function \code{.lec.SetSeed} sets Ig to \code{seed}. L'Ecuyer recommends to use the \code{\link[rlecuyer]{ResetStream}} functions instead of \code{SetSeed}.} 

\value{The (possibly modified) seed that has been used.}
\keyword{distribution}
\seealso{\code{\link[rlecuyer]{ResetNextSubstream}}}

\eof
\name{WriteState}
\alias{.lec.WriteState}
\alias{.lec.WriteStateFull}
\title{Output of the current state of streams}
\description{
\code{.lec.WriteState} writes the current state of given streams (Cg values).

\code{.lec.WriteStateFull} writes the values of all internal state variables
                        of given streams. 
}
\usage{
.lec.WriteState (names)

.lec.WriteStateFull (names)
}
\arguments{
  \item{names}{a character string or a vector of character strings
    naming the streams.}
}
\value{None}
\keyword{distribution}

\eof
\name{internal}
\alias{.lec.init}
\alias{.lec.exit}
\alias{.lec.StreamExists}
\title{Internal functions}
\description{Internal functions, it is not recommended to use them from outside of the package.

\code{.lec.init} initializes the workspace: removes old and creates new
  global object \cr \code{.lec.Random.seed.table}. It also 
  allocates memory for the current stream used by \cr
  \code{\link{.lec.CurrentStream}}.

\code{.lec.exit} removes the global object \code{.lec.Random.seed.table} and
  frees memory used for the current stream.

\code{.lec.StreamExists} returns \code{TRUE} if the stream is found in
  \code{.lec.Random.seed.table}, otherwise \code{FALSE}.
}

\usage{
.lec.init ()

.lec.exit ()

.lec.StreamExists (name)
}

\arguments{
  \item{name}{name of the stream.}
}
\keyword{internal}


\eof
\name{uniform}
\alias{.lec.uniform}
\alias{.lec.uniform.int}
\title{Generate random numbers}
\description{
\code{.lec.uniform} generates \eqn{U(0,1)} random numbers.

\code{.lec.uniform.int} generates random numbers from the discrete uniform
                        distribution over integers.
}
\usage{
.lec.uniform (name, n = 1)

.lec.uniform.int (name, n = 1, a = 0, b = 10)
}
\arguments{
  \item{name}{name of the stream.}
  \item{n}{number of random numbers to be generated.}
  \item{a,b}{interval from which the integer random numbers should be generated.}
}
\value{A vector of \eqn{n} random numbers.}
\details{\code{.lec.uniform} and \code{.lec.uniform.int}, respectively, are wrapper functions for the C
  functions \code{RngStream_RandU01} and \code{RngStream_RandInt}, respectively (L'Ecuyer et al, 2002). 

Note: Since the stream is here identified by \code{name}, there is no need for using the \code{\link[rlecuyer]{CurrentStream}} pair.
}
\references{P. L'Ecuyer, R. Simard, E.J.Chen and W.D.Kelton: An
  Object-Oriented Random-Number Package With Many Long Streams and
  Substreams; Operations Research, vol. 50, nr. 6, 2002.}
\examples{
nstreams <- 10       # number of streams
seed<-rep(1,6)
.lec.SetPackageSeed(seed)
names <- paste("mystream",1:nstreams,sep="")
.lec.CreateStream(names)
for (i in 1:nstreams)   # generate 10 RNs from each stream
      print(.lec.uniform(names[i],10))
.lec.DeleteStream(names)
}
\keyword{distribution}
\seealso{\code{\link[rlecuyer]{.lec.CurrentStream}}}

\eof
